# Changelog

## griffe-warnings-deprecated Insiders

### 2.0.0 <small>March 20, 2024</small> { id="1.0.0" }

- Rename project from `griffe-typing-deprecated` to `griffe-warnings-deprecated`

### 1.0.0 <small>July 15, 2023</small> { id="1.0.0" }

- Release first Insiders version
